django-xross documentation
==========================
https://github.com/idlesign/django-xross



Description
-----------

*Reusable application for Django nicely bridging client and server sides.*

Streamline you server and client interaction using some declarative techniques in your HTML,
and a couple of xross functions in your views.



Requirements
------------

1. Python 3.3+
2. Django 1.4+
3. jQuery (make it available in templates)



Table of Contents
-----------------

.. toctree::
    :maxdepth: 2

    quickstart
    python
    javascript



Get involved into django-xross
------------------------------

**Submit issues.** If you spotted something weird in application behavior or want to propose a feature you can do
that at https://github.com/idlesign/django-xross/issues

**Write code.** If you are eager to participate in application development, fork it
at https://github.com/idlesign/django-xross, write your code, whether it should be a bugfix or a feature
implementation, and make a pull request right from the forked project page.

**Spread the word.** If you have some tips and tricks or any other words in mind that you think might be of interest
for the others — publish it.
